@@ -1,9 +1,8 @@
-from __future__ import print_function
+# from __future__ import print_function
 from collection import Collection, Scorer, Concatenation
 from clustering import Clustering, Partition
 from distance_matrix import DistanceMatrix
-from optimiser import Optimiser
-from plotter import Plotter
-from simulator import Simulator
+# from optimiser import Optimiser
+# from plotter import Plotter
+# from simulator import Simulator
 from tree import Tree
-from utils import fileIO
